@@ -1,21 +1,26 @@
 #!/usr/bin/env python3
 
-import requests
-import os
+# SPDX-License-Identifier: MIT
+
 import argparse
-from xml.etree import ElementTree
-from collections import namedtuple, OrderedDict
-import subprocess
 import copy
+import os
+import subprocess
+from urllib.parse import parse_qs, urlparse
+from collections import namedtuple
 from queue import Queue
 from threading import Thread
-from cairosvg import svg2png
+from xml.etree import ElementTree
 
-namespaces = {"svg": "http://www.w3.org/2000/svg", "xlink": "http://www.w3.org/1999/xlink"}
+import requests
+
+namespaces = {"svg": "http://www.w3.org/2000/svg",
+              "xlink": "http://www.w3.org/1999/xlink"}
 
 Image = namedtuple("Image", ["id", "fname", "ts_in", "ts_out"])
 Frame = namedtuple("Frame", ["fname", "ts_in", "ts_out"])
 
+
 class Scrape:
     def __init__(self, host, id):
         self.host = host
@@ -39,16 +44,18 @@ class Scrape:
         url = "{}/deskshare/deskshare.mp4".format(self.baseurl)
         req = requests.get(url)
         if req.status_code == 200:
-           open(os.path.join(self.out, "deskshare.mp4"), "wb").write(req.content)
-           return True
+            fname = os.path.join(self.out, "deskshare.mp4")
+            open(fname, "wb").write(req.content)
+            return True
         return False
 
     def fetch_webcams(self):
         url = "{}/video/webcams.mp4".format(self.baseurl)
         req = requests.get(url)
         if req.status_code == 200:
-           open(os.path.join(self.out, "webcams.mp4"), "wb").write(req.content)
-           return True
+            fname = os.path.join(self.out, "webcams.mp4")
+            open(fname, "wb").write(req.content)
+            return True
         return False
 
     def fetch_image(self):
@@ -62,9 +69,9 @@ class Scrape:
             e.attrib["{http://www.w3.org/1999/xlink}href"] = fname
             if "id" in e.attrib:
                 self.images.append(Image(id=e.attrib["id"],
-                                        fname=fname,
-                                        ts_in=float(e.attrib["in"]),
-                                        ts_out=float(e.attrib["out"])))
+                                         fname=fname,
+                                         ts_in=float(e.attrib["in"]),
+                                         ts_out=float(e.attrib["out"])))
             self.workq.task_done()
 
     def fetch_images(self, tree=None):
@@ -74,7 +81,8 @@ class Scrape:
             for i in range(os.cpu_count()):
                 Thread(target=Scrape.fetch_image, args=(self,)).start()
             self.fetch_images(self.shapes)
-            open(os.path.join(self.out, "shapes.svg"), "wb").write(ElementTree.tostring(self.shapes))
+            fname = os.path.join(self.out, "shapes.svg")
+            open(fname, "wb").write(ElementTree.tostring(self.shapes))
             self.workq.join()
             return
 
@@ -113,7 +121,7 @@ class Scrape:
 
         t = 0.0
         for ts in self.timestamps[1:]:
-            self.workq.put((t,ts))
+            self.workq.put((t, ts))
             t = ts
         self.workq.join()
 
@@ -139,16 +147,20 @@ class Scrape:
                     shapes.remove(e)
             fname = os.path.join("frames", "shapes{}.png".format(timestamp))
             fnamesvg = os.path.join("frames", "shapes{}.svg".format(timestamp))
-            open(os.path.join(self.out, fnamesvg), "wb").write(ElementTree.tostring(shapes))
-            subprocess.run(["inkscape", "--export-png={}".format(fname), "--export-area-drawing", fnamesvg], cwd=self.out, stdout=subprocess.PIPE, stderr=subprocess.PIPE)
+            shapestr = ElementTree.tostring(shapes)
+            open(os.path.join(self.out, fnamesvg), "wb").write(shapestr)
+            subprocess.run(["inkscape", "--export-png={}".format(fname),
+                            "--export-area-drawing", fnamesvg],
+                           cwd=self.out, stdout=subprocess.PIPE,
+                           stderr=subprocess.PIPE)
             frame = Frame(fname=fname, ts_in=timestamp, ts_out=ts_out)
             self.frames.append(frame)
             self.workq.task_done()
 
-
     def make_visible(self, tree, timestamp):
         for e in tree.findall("svg:g", namespaces):
-            if "timestamp" in e.attrib and float(e.attrib["timestamp"]) <= timestamp:
+            if ("timestamp" in e.attrib and
+               float(e.attrib["timestamp"]) <= timestamp):
                 style = e.attrib["style"].split(";")
                 style.remove("visibility:hidden")
                 e.attrib["style"] = ";".join(style)
@@ -164,18 +176,61 @@ class Scrape:
         f.close()
 
     def render_slides(self):
-        subprocess.run(["ffmpeg", "-f", "concat", "-i", "concat.txt", "-pix_fmt", "yuv420p", "-y", "slides.mp4"], cwd=self.out, stderr=subprocess.PIPE)
+        subprocess.run(["ffmpeg", "-f", "concat", "-i", "concat.txt",
+                        "-pix_fmt", "yuv420p", "-y", "slides.mp4"],
+                       cwd=self.out, stderr=subprocess.PIPE)
+
 
 def main():
     parser = argparse.ArgumentParser(description='Scrape Big Blue Button')
-    parser.add_argument('host', help="Hostname")
-    parser.add_argument('id', help="Meeting id")
-    parser.add_argument('--no-webcam', action='store_true', help="Don't scrape webcam")
-    parser.add_argument('--no-deskshare', action='store_true', help="Don't scrape deskshare")
+    parser.add_argument('host', help="Hostname or full Meeting URL")
+    parser.add_argument('id', help="Meeting id", nargs='?')
+    parser.add_argument('--no-webcam', action='store_true',
+                        help="Don't scrape webcam")
+    parser.add_argument('--no-deskshare', action='store_true',
+                        help="Don't scrape deskshare")
 
     args = parser.parse_args()
+    host = args.host
+    meeting_id = args.id
 
-    scrape = Scrape(args.host, args.id)
+    # If only one parameter is given, assume it is a full meeting URL and
+    # extract host and meeting_id
+    if meeting_id is None:
+        url = urlparse(host)
+        host = url.netloc
+        if host is None:
+            print("!! Bad meeting URL. Either specify hostname and meeting id"
+                  " or the full URL of the recording")
+            return 1
+        qs = parse_qs(url.query)
+        if "meetingId" not in qs:
+            print("!! No meeting id given, and no meeting id found in URL")
+            return 1
+        meeting_id = qs["meetingId"][0]
+    else:
+        print("ii Usage of <host> <id> arguments is deprecated. "
+              "Use <meeting url> as single argument instead.")
+
+    try:
+        subprocess.run(["ffmpeg", "-h"],
+                       stderr=subprocess.DEVNULL,
+                       stdout=subprocess.DEVNULL)
+    except OSError:
+        print("!! ffmpeg not found. Please install it and make sure it is"
+              " available in your PATH.")
+        return 1
+
+    try:
+        subprocess.run(["inkscape", "--help"],
+                       stderr=subprocess.DEVNULL,
+                       stdout=subprocess.DEVNULL)
+    except OSError:
+        print("!! inkscape not found. Please install it and make sure it is"
+              "available in your PATH.")
+        return 1
+
+    scrape = Scrape(host, meeting_id)
     print("++ Scrape from server")
     scrape.create_output_dir()
     scrape.fetch_shapes()
